@@ -15,10 +15,13 @@
 #    under the License.
 
 from tempest.api.network import base
+from tempest import config
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
 
+CONF = config.CONF
+
 
 class NetworksNegativeTestJSON(base.BaseNetworkTest):
     """Negative tests of network"""
@@ -89,7 +92,9 @@ class NetworksNegativeTestJSON(base.BaseNetworkTest):
         self.assertRaises(lib_exc.NotFound,
                           self.ports_client.create_port,
                           network_id=non_exist_net_id,
-                          name=data_utils.rand_name(self.__class__.__name__))
+                          name=data_utils.rand_name(
+                              self.__class__.__name__,
+                              prefix=CONF.resource_name_prefix))
 
     @decorators.attr(type=['negative'])
     @decorators.idempotent_id('cf8eef21-4351-4f53-adcd-cc5cb1e76b92')
