@@ -14,21 +14,16 @@
 
 import copy
 
-from tempest.lib.api_schema.response.compute.v2_1 import limits as limitv21
+from tempest.lib.api_schema.response.compute.v2_39 import limits as limitv239
 
-# Compute microversion 2.36:
+# Compute microversion 2.57:
 # remove attributes in get_limit:
-#    'maxSecurityGroupRules',
-#    'maxSecurityGroups',
-#    'maxTotalFloatingIps',
-#    'totalFloatingIpsUsed',
-#    'totalSecurityGroupsUsed'
+#    'maxPersonality',
+#    'maxPersonalitySize'
 
-get_limit = copy.deepcopy(limitv21.get_limit)
+get_limit = copy.deepcopy(limitv239.get_limit)
 
-for item in ['maxSecurityGroupRules', 'maxSecurityGroups',
-             'maxTotalFloatingIps', 'totalFloatingIpsUsed',
-             'totalSecurityGroupsUsed']:
+for item in ['maxPersonality', 'maxPersonalitySize']:
     get_limit['response_body']['properties']['limits']['properties'][
         'absolute']['properties'].pop(item)
     get_limit['response_body']['properties']['limits']['properties'][
